import pytest

from yascc.camelcase import decamelize

from .django_rest_framework_camelcase import underscoreize


def test_decamelize(camelized_dict: dict, decamelized_dict: dict) -> None:
    got = decamelize(camelized_dict)
    assert got == decamelized_dict


@pytest.mark.parametrize("impl", [decamelize, underscoreize], ids=["c", "drf"])
def test_decamelize_benchmark(benchmark, camelized_list_of_dict, impl):
    benchmark(impl, camelized_list_of_dict)


def test_decamelize_nested_dict(camelized_nested_dict, decamelized_nested_dict) -> None:
    assert decamelize(camelized_nested_dict) == decamelized_nested_dict


def test_decamelize_list_of_dict(camelized_list_of_dict, decamelized_list_of_dict) -> None:
    assert decamelize(camelized_list_of_dict) == decamelized_list_of_dict



from __future__ import annotations

from typing import Any

from _case import _to_snake_case

from .common import apply


def to_snake_case(src: str) -> str:
    return str(_to_snake_case(src))


def decamelize(d: dict[str, Any] | list[Any]) -> dict[str, Any] | list[Any]:
    return apply(to_snake_case, d)
